Generic summarise function for tests
Value
A function that can be used in Summarise that returns a data frame with the columns
rejection_X
rejection_Y
...
Where X, Y, ... are the alpha levels given in the argument
Details
For details on the evaluation of the arguments see summarise_estimator.
If the test-statistic used is not a p-value, alpha refers to the critical value. The test is assumed to reject if the test statistic is smaller than the critical value. To switch direction take the negative of both values.
Examples
# \donttest{
condition <- merge(
assumptions_delayed_effect(),
design_fixed_followup(),
by=NULL
) |>
tail(4) |>
head(1)
summarise_all <- create_summarise_function(
logrank=summarise_test(alpha=1-c(0.5, 0.9, 0.95, 0.99)),
logrank_zval=summarise_test(alpha=qnorm(1-c(0.5, 0.9, 0.95, 0.99)), teststat=z)
)
# runs simulations
sim_results <- runSimulation(
design=condition,
replications=100,
generate=generate_delayed_effect,
analyse=list(
logrank=analyse_logrank(),
logrank_zval=function(condition, dat, fixed_objects=NULL){
tmp <- analyse_logrank()(condition, dat, fixed_objects)
tmp$z <- qnorm(tmp$p)
tmp
}
),
summarise = summarise_all
)
#>
#>
Replications: 100; RAM Used: 213 Mb;
#> Conditions: delay=121., hzrd_c=0.0009, hzrd_t=0.0006, rndm_w=0.0001, n_trt=150, n_ctrl=150, follwp=730., rcrtmn=182.
#>
|
| | 0%
|
| | 1%
|
|= | 2%
|
|== | 3%
|
|== | 4%
|
|== | 5%
|
|=== | 6%
|
|==== | 7%
|
|==== | 8%
|
|==== | 9%
|
|===== | 10%
|
|====== | 11%
|
|====== | 12%
|
|====== | 13%
|
|======= | 14%
|
|======== | 15%
|
|======== | 16%
|
|======== | 17%
|
|========= | 18%
|
|========== | 19%
|
|========== | 20%
|
|========== | 21%
|
|=========== | 22%
|
|============ | 23%
|
|============ | 24%
|
|============ | 25%
|
|============= | 26%
|
|============== | 27%
|
|============== | 28%
|
|============== | 29%
|
|=============== | 30%
|
|================ | 31%
|
|================ | 32%
|
|================ | 33%
|
|================= | 34%
|
|================== | 35%
|
|================== | 36%
|
|================== | 37%
|
|=================== | 38%
|
|==================== | 39%
|
|==================== | 40%
|
|==================== | 41%
|
|===================== | 42%
|
|====================== | 43%
|
|====================== | 44%
|
|====================== | 45%
|
|======================= | 46%
|
|======================== | 47%
|
|======================== | 48%
|
|======================== | 49%
|
|========================= | 50%
|
|========================== | 51%
|
|========================== | 52%
|
|========================== | 53%
|
|=========================== | 54%
|
|============================ | 55%
|
|============================ | 56%
|
|============================ | 57%
|
|============================= | 58%
|
|============================== | 59%
|
|============================== | 60%
|
|============================== | 61%
|
|=============================== | 62%
|
|================================ | 63%
|
|================================ | 64%
|
|================================ | 65%
|
|================================= | 66%
|
|================================== | 67%
|
|================================== | 68%
|
|================================== | 69%
|
|=================================== | 70%
|
|==================================== | 71%
|
|==================================== | 72%
|
|==================================== | 73%
|
|===================================== | 74%
|
|====================================== | 75%
|
|====================================== | 76%
|
|====================================== | 77%
|
|======================================= | 78%
|
|======================================== | 79%
|
|======================================== | 80%
|
|======================================== | 81%
|
|========================================= | 82%
|
|========================================== | 83%
|
|========================================== | 84%
|
|========================================== | 85%
|
|=========================================== | 86%
|
|============================================ | 87%
|
|============================================ | 88%
|
|============================================ | 89%
|
|============================================= | 90%
|
|============================================== | 91%
|
|============================================== | 92%
|
|============================================== | 93%
|
|=============================================== | 94%
|
|================================================ | 95%
|
|================================================ | 96%
|
|================================================ | 97%
|
|================================================= | 98%
|
|==================================================| 99%
|
|==================================================| 100%
sim_results[, grepl("rejection", names(sim_results))]
#> # A tibble: 1 × 8
#> logrank.rejection_0.5 logrank.rejection_0.1 logrank.rejection_0.05
#> <dbl> <dbl> <dbl>
#> 1 1 0.91 0.85
#> # ℹ 5 more variables: logrank.rejection_0.01 <dbl>,
#> # logrank_zval.rejection_0 <dbl>,
#> # `logrank_zval.rejection_-1.2815515655446` <dbl>,
#> # `logrank_zval.rejection_-1.64485362695147` <dbl>,
#> # `logrank_zval.rejection_-2.32634787404084` <dbl>
# }